==> request-tracker4_4.4.7+dfsg.orig-third-party-source.tar.gz: rt-4.4.7/devel/third-party/ckeditor-src/plugins/link/lang/fo.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'fo', {
	acccessKey: 'Snarvegisknöttur',
	advanced: 'Fjølbroytt',
	advisoryContentType: 'Vegleiðandi innihaldsslag',
	advisoryTitle: 'Vegleiðandi heiti',
	anchor: {
		toolbar: 'Ger/broyt marknastein',
		menu: 'Eginleikar fyri marknastein',
		title: 'Eginleikar fyri marknastein',
		name: 'Heiti marknasteinsins',
		errorName: 'Vinarliga rita marknasteinsins heiti',
		remove: 'Strika marknastein'
	},
	anchorId: 'Eftir element Id',
	anchorName: 'Eftir navni á marknasteini',
	charset: 'Atknýtt teknsett',
	cssClasses: 'Typografi klassar',
	emailAddress: 'Teldupost-adressa',
	emailBody: 'Breyðtekstur',
	emailSubject: 'Evni',
	id: 'Id',
	info: 'Tilknýtis upplýsingar',
	langCode: 'Tekstkós',
	langDir: 'Tekstkós',
	langDirLTR: 'Frá vinstru til høgru (LTR)',
	langDirRTL: 'Frá høgru til vinstru (RTL)',
	menu: 'Broyt tilknýti',
	name: 'Navn',
	noAnchors: '(Eingir marknasteinar eru í hesum dokumentið)',
	noEmail: 'Vinarliga skriva teldupost-adressu',
	noUrl: 'Vinarliga skriva tilknýti (URL)',
	other: '<annað>',
	popupDependent: 'Bundið (Netscape)',
	popupFeatures: 'Popup vindeygans víðkaðu eginleikar',
	popupFullScreen: 'Fullur skermur (IE)',
	popupLeft: 'Frástøða frá vinstru',
	popupLocationBar: 'Adressulinja',
	popupMenuBar: 'Skrábjálki',
	popupResizable: 'Stødd kann broytast',
	popupScrollBars: 'Rullibjálki',
	popupStatusBar: 'Støðufrágreiðingarbjálki',
	popupToolbar: 'Amboðsbjálki',
	popupTop: 'Frástøða frá íerva',
	rel: 'Relatión',
	selectAnchor: 'Vel ein marknastein',
	styles: 'Typografi',
	tabIndex: 'Tabulator indeks',
	target: 'Target',
	targetFrame: '<ramma>',
	targetFrameName: 'Vís navn vindeygans',
	targetPopup: '<popup vindeyga>',
	targetPopupName: 'Popup vindeygans navn',
	title: 'Tilknýti',
	toAnchor: 'Tilknýti til marknastein í tekstinum',
	toEmail: 'Teldupostur',
	toUrl: 'URL',
	toolbar: 'Ger/broyt tilknýti',
	type: 'Tilknýtisslag',
	unlink: 'Strika tilknýti',
	upload: 'Send til ambætaran'
} );

==> request-tracker5_5.0.1+dfsg.orig-third-party-source.tar.gz: rt-5.0.1/devel/third-party/ckeditor-src/plugins/link/lang/fo.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'fo', {
	acccessKey: 'Snarvegisknöttur',
	advanced: 'Fjølbroytt',
	advisoryContentType: 'Vegleiðandi innihaldsslag',
	advisoryTitle: 'Vegleiðandi heiti',
	anchor: {
		toolbar: 'Ger/broyt marknastein',
		menu: 'Eginleikar fyri marknastein',
		title: 'Eginleikar fyri marknastein',
		name: 'Heiti marknasteinsins',
		errorName: 'Vinarliga rita marknasteinsins heiti',
		remove: 'Strika marknastein'
	},
	anchorId: 'Eftir element Id',
	anchorName: 'Eftir navni á marknasteini',
	charset: 'Atknýtt teknsett',
	cssClasses: 'Typografi klassar',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'Teldupost-adressa',
	emailBody: 'Breyðtekstur',
	emailSubject: 'Evni',
	id: 'Id',
	info: 'Tilknýtis upplýsingar',
	langCode: 'Tekstkós',
	langDir: 'Tekstkós',
	langDirLTR: 'Frá vinstru til høgru (LTR)',
	langDirRTL: 'Frá høgru til vinstru (RTL)',
	menu: 'Broyt tilknýti',
	name: 'Navn',
	noAnchors: '(Eingir marknasteinar eru í hesum dokumentið)',
	noEmail: 'Vinarliga skriva teldupost-adressu',
	noUrl: 'Vinarliga skriva tilknýti (URL)',
	noTel: 'Please type the phone number', // MISSING
	other: '<annað>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Bundið (Netscape)',
	popupFeatures: 'Popup vindeygans víðkaðu eginleikar',
	popupFullScreen: 'Fullur skermur (IE)',
	popupLeft: 'Frástøða frá vinstru',
	popupLocationBar: 'Adressulinja',
	popupMenuBar: 'Skrábjálki',
	popupResizable: 'Stødd kann broytast',
	popupScrollBars: 'Rullibjálki',
	popupStatusBar: 'Støðufrágreiðingarbjálki',
	popupToolbar: 'Amboðsbjálki',
	popupTop: 'Frástøða frá íerva',
	rel: 'Relatión',
	selectAnchor: 'Vel ein marknastein',
	styles: 'Typografi',
	tabIndex: 'Tabulator indeks',
	target: 'Target',
	targetFrame: '<ramma>',
	targetFrameName: 'Vís navn vindeygans',
	targetPopup: '<popup vindeyga>',
	targetPopupName: 'Popup vindeygans navn',
	title: 'Tilknýti',
	toAnchor: 'Tilknýti til marknastein í tekstinum',
	toEmail: 'Teldupostur',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Ger/broyt tilknýti',
	type: 'Tilknýtisslag',
	unlink: 'Strika tilknýti',
	upload: 'Send til ambætaran'
} );
